@@ -9,17 +9,23 @@ import time
 import json
 import maintain_PlatoUtils
 import requests
+import gc
 
 def wrapNebula2Df(nebulaObj):
     '''将platoDB查询到的对象转为df'''
     # print(nebulaObj.column_names)
+    start=time.time()
     if nebulaObj.column_names is not None:
         columnList = [colItem.decode("utf8") for colItem in nebulaObj.column_names]
     else:
         return pd.DataFrame([])
+    end=time.time()
+    
+    start=time.time()
     dataList = []
     if nebulaObj.rows is not None:
-        for rowItem in tqdm.tqdm(nebulaObj.rows):
+        gc.disable()
+        for rowItem in nebulaObj.rows:
             rowList = []
             for colItem in rowItem.columns:
                 if type(colItem.value) == bytes:
@@ -27,8 +33,11 @@ def wrapNebula2Df(nebulaObj):
                 else:
                     rowList.append(colItem.value)
             dataList.append(rowList.copy())
+        gc.enable()
     else:
         return pd.DataFrame([])
+    end=time.time()
+    
     return pd.DataFrame(dataList, columns=columnList).drop_duplicates()
 
 def pdPlatoTypeSame(pdSeries,gType):
@@ -44,8 +53,28 @@ def pdPlatoTypeSame(pdSeries,gType):
             return True
     return False
 
+def delEdge(gClient,sysIdList,edgeType="*"):
+    '''删除与源节点sysIdList关联的边edgeType'''
+    if edgeType=="*":
+        relDf=wrapNebula2Df(gClient.execute_query("SHOW EDGES"))["Name"]
+        relList=relDf.values.flatten().tolist()
+    else:
+        relList=[edgeType]
+    for relItem in relList:
+        for srcSysIdItem in sysIdList:
+            relTailSysIdDf=wrapNebula2Df(gClient.execute_query("GO FROM {srcSysId} OVER {edgeName} BIDIRECT YIELD {edgeName}._dst AS tgtSysId".format(
+                srcSysId=srcSysIdItem,
+                edgeName=relItem)))
+            if relTailSysIdDf.shape[0]>0:
+                relTailSysIdList=relTailSysIdDf["tgtSysId"].values.flatten().tolist()
+                delOrderGroupStr=",".join(["{}->{}".format(srcSysIdItem,tailSysIdItem) for tailSysIdItem in relTailSysIdList])
+                delReverseGroupStr=",".join(["{}->{}".format(tailSysIdItem,srcSysIdItem) for tailSysIdItem in relTailSysIdList])
+                delGroupStr=",".join([delOrderGroupStr,delReverseGroupStr])
+                gClient.execute_query("DELETE EDGE {} {}".format(relItem,delGroupStr))
+
 def delVertex(gClient,sysIdList,delRel=True):
     '''（关联）删除节点'''
+    delReq={"data":[],"error_code":0}
     if delRel==True:
         relDf=wrapNebula2Df(gClient.execute_query("SHOW EDGES"))["Name"]
         relList=relDf.values.flatten().tolist()
@@ -67,19 +96,24 @@ def delVertex(gClient,sysIdList,delRel=True):
                 
 def existTag(nodeType,nodeIdAttr,nodeName,gClient):
     '''查看nodeType的nodeIdAttr为nodeName的节点是否在gClient中（gClient提前设定好图数据库）'''
-    searchTagDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}=='{nodeName}'|LIMIT 1".format(
-        nodeType=nodeType,
-        nodeIdAttr=nodeIdAttr,
-        nodeName=nodeName
-    )))
-    if searchTagDf.shape[0]>0:
-        return True
+    passTag=0
+    while passTag<5:
+        try:
+            searchTagDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}=='{nodeName}'|LIMIT 1".format(
+                nodeType=nodeType,
+                nodeIdAttr=nodeIdAttr,
+                nodeName=nodeName
+            )))
+            if searchTagDf.shape[0]>0:
+                return True
+        except:
+            passTag+=1
     return False
 
 def transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
                          tgtGHost,tgtGPort,tgtGUser,tgtGPassword,tgtGdbName,tgtGAPIUrl,edgeTypeList=[],
                          srcVertexKeynameDict={"srcNodeType":"srcNodeIdAttr"},csv2platoDTypeDict={"srcNodeIdAttr":"string"},
-                         batchSize=64,projectName="",platoAPIIP="9.135.95.249",platoAPIPort=8083):
+                         batchSize=64,projectName="",platoAPIIP="",platoAPIPort=8083):
     
     srcConnection_pool = ConnectionPool(srcGHost, srcGPort,network_timeout=300000)
     srcClient = GraphClient(srcConnection_pool)
@@ -249,20 +283,60 @@ def transferBetweenPlato(srcGHost,srcGPort,srcGUser,srcGPassword,srcGdbName,
     print(response.text)
     return response
 
+def existEdge(headType,headIdAttr,headIdVal,tailType,tailIdAttr,tailIdVal,edgeType,gClient):
+    '''查看头节点为headIdVal，尾节点为tailIdVal的edgeType边是否存在（gClient提前设定好图数据库）'''
+    searchEdgeDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {headType} WHERE {headType}.{headIdAttr}=='{headIdVal}'|\
+                                                        GO FROM $-.VertexID OVER {edgeType} WHERE  $$.{tailType}.{tailIdAttr}=='{tailIdVal}'|LIMIT 1\
+                                                            YIELD $$.{tailType}.{tailIdAttr}".format(
+                                                                                                headType=headType,
+                                                                                                headIdAttr=headIdAttr,
+                                                                                                headIdVal=headIdVal,
+                                                                                                edgeType=edgeType,
+                                                                                                tailType=tailType,
+                                                                                                tailIdAttr=tailIdAttr,
+                                                                                                tailIdVal=tailIdVal
+                                                                                            )))
+    if searchEdgeDf.shape[0]>0:
+        return True
+    return False
+
 if __name__=="__main__":
     
-    # srcGHost="9.135.95.249"
-    # srcGPort=13708
-    # srcGUser="root"
-    # srcGPassword="nebula"
-    # srcGdbName="company_product_field_musklin"
+    srcGHost=""
+    srcGPort=13708
+    srcGUser="root"
+    srcGPassword="nebula"
+    srcGdbName="company_product_field_musklin"
+    
+    srcConnection_pool = ConnectionPool(srcGHost, srcGPort,network_timeout=300000)
+    srcClient = GraphClient(srcConnection_pool)
+    srcClient.authenticate(srcGUser, srcGPassword)
+    srcClient.execute_query("use {}".format(srcGdbName))
+    
+    # start=time.time()
+    # adf=wrapNebula2Df(srcClient.execute_query("LOOKUP ON Token WHERE Token.TokenName=='深'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='圳'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='市'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='上'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='元'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='资'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='本'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='管'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='理'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='有'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
+    #                                             LOOKUP ON Token WHERE Token.TokenName=='限'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50"))
+    # end=time.time()
+    # print(end-start)
+    
+    # print(adf.head())
+    
     # srcVertexKeynameDict={
     #     "Company":"CompanyName",
     #     "Field":"FieldName"
     # }
     # edgeTypeList=["belongTo"]
 
-    # tgtGHost="9.135.95.249"
+    # tgtGHost=""
     # tgtGPort=13708
     # tgtGAPIUrl="http://{}:8083"
     # tgtGUser="root"
@@ -285,4 +359,4 @@ if __name__=="__main__":
     #                      edgeTypeList=[],
     #                      srcVertexKeynameDict=srcVertexKeynameDict,csv2platoDTypeDict=csv2platoDTypeDict)
     
-    pass
\ No newline at end of file
+    # pass
\ No newline at end of file
